.. This file is a part of the AnyBlok project
..
..    Copyright (C) 2014 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
..
.. This Source Code Form is subject to the terms of the Mozilla Public License,
.. v. 2.0. If a copy of the MPL was not distributed with this file,You can
.. obtain one at http://mozilla.org/MPL/2.0/.

AnyBlok
=======

AnyBlok is a Python framework allowing to create highly dynamic and modular
applications on top of SQLAlchemy.

AnyBlok is released under the terms of the `Mozilla Public License`.

See the `latest documentation <http://docs.anyblok.org/>`_
